==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServiceCatalogControllerManagerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceCatalogControllerManagerListBuilder extends io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList,io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListBuilder>{
  public ServiceCatalogControllerManagerListBuilder() {
    this(false);
  }
  public ServiceCatalogControllerManagerListBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceCatalogControllerManagerList(), validationEnabled);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceCatalogControllerManagerList(), validationEnabled);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance) {
    this(fluent, instance, false);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance) {
    this(instance,false);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList build() {
    ServiceCatalogControllerManagerList buildable = new ServiceCatalogControllerManagerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceCatalogControllerManagerListBuilder that = (ServiceCatalogControllerManagerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServiceCatalogControllerManagerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceCatalogControllerManagerListBuilder extends io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList,io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListBuilder>{
  public ServiceCatalogControllerManagerListBuilder() {
    this(false);
  }
  public ServiceCatalogControllerManagerListBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceCatalogControllerManagerList(), validationEnabled);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceCatalogControllerManagerList(), validationEnabled);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance) {
    this(fluent, instance, false);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance) {
    this(instance,false);
  }
  public ServiceCatalogControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerList build() {
    ServiceCatalogControllerManagerList buildable = new ServiceCatalogControllerManagerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceCatalogControllerManagerListBuilder that = (ServiceCatalogControllerManagerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
